/*
Runs simulations of circle competitiveness

Author:
	Ismail Khan (2015-2017)

Notes:
	- Simulations based on BASELINE preferences
	- Output also contains circle 402800's rankings (see note below for justification)
	
Special note on circles 402700 & 402800:
	Inspector 40838 was believed to be in 402700 at the time of baseline, so 402700 was 
	included in GUJRANWALA group 5. However, inspector 40838 was actually in 402800 at
	the time. We thus have 40838's preferences, but for the wrong group (402700 instead
	of 402800).

NOTE:
	The simulations of postings have been commented out, please uncomment if you would 
	like to rerun the simulations.
	

*/

******************************************************************************
* Initial setup
******************************************************************************

clear all
set more off
pause on
set seed 123124
cap cd "$PAKTAX2_ANALYSIS"

* Declare variables used throughout file
local num_y1_circles = 410
local num_missing_treat_rankings = 2
local num_missing_contr_rankings = 27

* Declare input files
local y2_analysis_data =  			"TP Analysis/Coded Data/TP Y2 Analysis Data w Y1 Treatment.dta"
local pilot_list1 = 				"Data\Randomization\Output\Year 1/130803 Multan PILOT Transfers Randomization Output MERGE 51135.dta"
local pilot_list2 = 				"Data\Randomization\Output\Year 1/130726 Lahore PILOT Transfers Randomization Output MERGE 150.dta"
local base_pref_file = 				"Data/Cleaned Data/Preference Data/Compiled Preference Data"

* Declare output files
local posting_simulation = 			"TP Analysis/Coded Data/Posting simulation"
local analysis_output = 			"TP Analysis/Coded Data/Baseline competitiveness"
local base_simulation_prefs = 		"TP Analysis/Coded Data/Cleaned baseline preferences for simulation"

******************************************************************************
* Dataset prep
******************************************************************************

* Save list of circles in pilot (might not use this later)
use "`pilot_list1'", clear
append using "`pilot_list2'"
keep circle_id
isid circle_id
tempfile pilot_circles
sa `pilot_circles'

* Used to verify that preference list contains the right circles
use "`y2_analysis_data'", clear
keep if treatment_y1 == 1
keep circle_id hr_id
duplicates drop
tempfile y1_treat_list
sa `y1_treat_list'


******************************************************************************
* Load and prep baseline preferences
******************************************************************************

use "`base_pref_file'", clear

* Remove pilot circles
merge m:1 circle_id using `pilot_circles'
keep if _m == 1
drop _m

* Modify preference data (some own_hr_ids are missing): note that this does not apply to any treatment circles, so we're OK
replace own_hr_id = 81027 if partition_name == "MULTAN" & group == 6 & mi(own_hr_id)
replace own_hr_id = 31260 if partition_name == "SARGODHA" & group == 2 & mi(own_hr_id)
replace own_hr_id = 31161 if partition_name == "FAISALABAD" & group == 5 & (own_hr_id == 33000 | mi(own_hr_id))
replace own_hr_id = 61013 if partition_name == "LAHORE" & group == 12 & mi(own_hr_id)
replace hr_id = 61013 if partition_name == "LAHORE" & group == 12 & circle_id == 611602
replace own_hr_id = 60144 if partition_name == "LAHORE" & group == 2 & mi(own_hr_id)
replace own_hr_id = 61007 if partition_name == "LAHORE" & group == 4 & mi(own_hr_id)
bys partition_name group own_hr_id hr_id: egen seq = seq() // Tagged because groups below have two missing pref sheets
replace own_hr_id = 61009 if partition_name == "LAHORE" & group == 8 & mi(own_hr_id) & seq == 1
replace own_hr_id = 81072 if partition_name == "LAHORE" & group == 8 & mi(own_hr_id) & seq == 2
replace own_hr_id = 60226 if partition_name == "LAHORE" & group == 10 & mi(own_hr_id) & seq == 1
replace own_hr_id = 50095 if partition_name == "LAHORE" & group == 10 & mi(own_hr_id) & seq == 2
drop seq

drop own_circle // variable is not accurate
gen own_circle = 1 if own_hr_id == hr_id

* Save list of circles for which preferences are collected
preserve
	keep if own_circle == 1
	keep partition_name group circle_id own_hr_id
	ren own_hr_id hr_id
	duplicates drop
	tempfile hr_circle_mapping
	save `hr_circle_mapping'
restore

* Test: Check num of missing pref sheets, and total number of circles
preserve
	keep if own_circle == 1
	keep circle_id ranking treatment
	duplicates drop circle_id, force
	count
	assert `r(N)' == `num_y1_circles'
	count if mi(ranking) & treatment == 0
	assert `r(N)' == `num_missing_contr_rankings'
	count if mi(ranking) & treatment == 1 
	assert `r(N)' == `num_missing_treat_rankings'
restore

drop if missing(own_hr_id) // Drop circles with no inspector

* Test: Ensure that every inspector has at least one "own_circle"
preserve
	egen has_own_circle = total(own_circle), by(partition_name group own_hr_id)
	assert has_own_circle >= 1 // This isn't exactly == 1 because sometimes an inspector puts his additional charge in the list of preferences
restore

* Test: Ensure that inspectors have not submitted >1 distinct preferences for the same group
preserve
	keep partition_name group own_hr_id ranking circle_id
	duplicates drop
	duplicates tag partition_name group own_hr_id circle_id, gen(d)
	*assert !d
restore

rename hr_id circle_hr_id
rename own_hr_id hr_id

* Create own_circle_id variable
gen own_circle_id_temp = circle_id if own_circle == 1
egen own_circle_id = max(own_circle_id_temp), by(partition_name group hr_id)
drop own_circle_id_temp

* Remove unnecessary variables
keep partition_name group hr_id ranking circle_id own_circle
duplicates drop
duplicates tag partition_name group hr_id circle_id, gen(d)

* keep only one preference sheet for inspectors with >1 preference sheets
drop if hr_id == 11661 		& circle_id == 108101 	& ranking == 2
drop if hr_id == 11661 		& circle_id == 107800 	& ranking == 3
drop if hr_id == 11661 		& circle_id == 107700 	& ranking == 4
drop if hr_id == 11661 		& circle_id == 100200 	& ranking == 5
drop if hr_id == 11661 		& circle_id == 108300 	& ranking == 7
drop if hr_id == 11661 		& circle_id == 108000 	& ranking == 8
drop if hr_id == 11511 		& circle_id == 101200 	& ranking == 1
drop if hr_id == 11511 		& circle_id == 101300 	& ranking == 2
drop if hr_id == 11511 		& circle_id == 102100 	& ranking == 3
drop if hr_id == 11511 		& circle_id == 100701 	& ranking == 4
drop if hr_id == 11511 		& circle_id == 107200 	& ranking == 6
drop if hr_id == 11511 		& circle_id == 107902 	& ranking == 7
drop if hr_id == 11511 		& circle_id == 107600 	& ranking == 8
drop if hr_id == 11511 		& circle_id == 109100 	& ranking == 9
drop if hr_id == 11511 		& circle_id == 109000 	& ranking == 10
drop if hr_id == 11511 		& circle_id == 105600 	& ranking == 11
drop if hr_id == 11671 		& circle_id == 107600 	& ranking == 1
drop if hr_id == 11671 		& circle_id == 107200 	& ranking == 2
drop if hr_id == 11671 		& circle_id == 107902 	& ranking == 5
drop if hr_id == 11671 		& circle_id == 101200 	& ranking == 6
drop if hr_id == 11671 		& circle_id == 100701 	& ranking == 7
drop if hr_id == 11671 		& circle_id == 101300 	& ranking == 8
drop if hr_id == 11671 		& circle_id == 101800 	& ranking == 9
drop if hr_id == 11671 		& circle_id == 105600 	& ranking == 10
drop if hr_id == 11671 		& circle_id == 102100 	& ranking == 11
drop if hr_id == 81201 		& circle_id == 808700 	& ranking == 1
drop if hr_id == 81201 		& circle_id == 808800 	& ranking == 2
drop if hr_id == 112542 	& circle_id == 1101400 	& ranking == 1
drop if hr_id == 112542 	& circle_id == 1100713 	& ranking == 2
drop if hr_id == 112542 	& circle_id == 1100900 	& ranking == 3

* Test: Ensure that inspectors have not submitted >1 distinct preferences for the same group
preserve
	keep partition_name group hr_id ranking circle_id
	duplicates drop
	duplicates tag partition_name group hr_id circle_id, gen(d)
	assert !d
restore

drop d

tempfile preferences
sa `preferences'


******************************************************************************
* Create analysis variables using preferences 
******************************************************************************

use `preferences', clear

* Normalize all rankings
bys partition_name group hr_id: egen rank_count = count(ranking)
bys partition_name group hr_id: egen max_rank = max(ranking)
assert max_rank == rank_count if rank_count > 0
gen norm_ranking = 1 + ( ((ranking-1)/(rank_count-1)) * (10-1) ) if rank_count > 0
drop rank_count max_rank

* Add analysis variables
gen ranked_first = ranking == 1
collapse (sum) num_ranked_first=ranked_first (count) num_rankings=ranking (mean) top_choice_ranking_average=norm_ranking, by(circle_id)
gen top_choice_fraction_ranked_first = num_ranked_first / num_rankings
assert top_choice_fraction_ranked_first <= 1
drop num_ranked_first num_rankings

tempfile circle_popularity
sa `circle_popularity'


******************************************************************************
* Fill in missing rankings 
******************************************************************************

use `preferences', clear

* Identify preferences sheets with at least one ranking missing
bys partition_name group hr_id: gen missing_ranking = mi(ranking)
bys partition_name group hr_id: egen any_missing_ranking = max(missing_ranking)

* Create variable with maximum ranking of any preference sheet
bys partition_name group hr_id: egen max_ranking = max(ranking)
replace max_ranking = 0 if mi(max_ranking)

* Save non-missing rankings
preserve
	keep if !mi(ranking)
	isid partition_name group hr_id ranking
	tempfile notmissing
	save `notmissing'
restore

keep if mi(ranking)

* Assign missing ranking
bys partition_name group hr_id: gen rand = runiform()
bys partition_name group hr_id (rand): replace ranking = _n + max_ranking

drop rand

append using `notmissing'


******************************************************************************
* Normalize rankings, and check that they make sense (can be listed as 1,2,..,10)
******************************************************************************

* Check that rankings make sense
bys partition_name group hr_id: egen rank_sum = total(ranking)
bys partition_name group hr_id: egen rank_count = count(ranking)
assert rank_sum == (rank_count * (rank_count + 1))/2 if rank_count > 0
drop rank_sum rank_count

* Normalize all rankings
bys partition_name group hr_id: egen rank_count = count(ranking)
bys partition_name group hr_id: egen max_rank = max(ranking)
assert max_rank == rank_count if rank_count > 0
gen norm_ranking = 1 + ( ((ranking-1)/(rank_count-1)) * (10-1) ) if rank_count > 0
drop rank_count max_rank

sa "`base_simulation_prefs'", replace

******************************************************************************
* Reshape preferences 
******************************************************************************

isid partition_name group hr_id ranking
ren circle_id preference
keep partition_name group hr_id preference ranking norm_ranking
reshape wide preference norm_ranking, i(partition_name group hr_id) j(ranking)

tempfile preferences_wide
save `preferences_wide'


******************************************************************************
* Save top choice circle for each inspector in each group
******************************************************************************

keep partition_name group hr_id preference1
ren preference1 top_choice
tempfile top_choice_circle
sa `top_choice_circle'


******************************************************************************
* Simulate postings
******************************************************************************

/*
forval iter = 1/1000 {

	use `preferences_wide', clear
	
	* Assign random rank to each inspector
	gen rand = runiform()
	bys partition_name group (rand) : gen rank = _n
	drop rand

	* Copy preference list for each inspector
	forval i = 1/11 {
		gen circle`i' = preference`i'
	}
	
	gen posting = .

	* Calculate postings for each inspector based on simulated rank
	forval i = 1/11 {
		egen next_available = rowfirst(preference*)
		replace posting = next_available if rank == `i'
		drop next_available
		
		gen first = 1 if rank == `i'
		bys partition_name group (first) : gen alreadytaken`i' = posting[1]
		drop first
		
		forval j = 1 / 11 {
			replace preference`j' = . if preference`j' == alreadytaken`i'
		}
	}

	* Calculate ranking of each inspectors' new circle
	gen posting_circle_rank = .
	forval i = 1/11 {
		replace posting_circle_rank = norm_ranking`i' if posting == circle`i'
	}
	assert posting_circle_rank != .
	
	keep partition_name group hr_id posting_circle_rank
	ren posting_circle_rank posting_circle_rank`iter'
	
	if `iter' == 1 {
		tempfile exprank
		save `exprank'
	}
	else {
		merge 1:1 partition_name group hr_id using `exprank', assert(match) nogen
		save `exprank', replace
	}
}

save "`posting_simulation'", replace
*/

******************************************************************************
* Create analysis dataset
******************************************************************************

use "`posting_simulation'", clear

* Calculate standard deviation and average of posted circle rank
egen posted_circle_rank_avg = rowmean(posting_circle_rank1000-posting_circle_rank1) 
egen posted_circle_rank_sd = rowsd(posting_circle_rank1000-posting_circle_rank1)
drop posting_circle_rank1000-posting_circle_rank1

* Add analysis variables
merge 1:1 partition_name group hr_id using `top_choice_circle', assert(match) nogen
ren top_choice circle_id
merge m:1 circle_id using `circle_popularity', assert(2 3) keep(match) nogen
drop circle_id

* Add inspector's circle as baseline
merge 1:m partition_name group hr_id using `hr_circle_mapping', assert(2 3) nogen
count
assert `r(N)' == `num_y1_circles'

order circle_id, after(group)


******************************************************************************
* Save results 
******************************************************************************

sa "`analysis_output'", replace

