/*
* Change in rank according to Y1 and Baseline preferences for inspectors in the TREATMENT GROUP.
*/

************************************************************************************************************************
* Data setup
************************************************************************************************************************

clear all
set more off
cap cd "$PAKTAX2_ANALYSIS"

************************************************************************************************************************
* Prepare datasets
************************************************************************************************************************

* Load list of pilot circles
use "Data\Randomization\Output\Year 1/130803 Multan PILOT Transfers Randomization Output MERGE 51135.dta", clear
append using "Data\Randomization\Output\Year 1/130726 Lahore PILOT Transfers Randomization Output MERGE 150.dta"
keep circle_id
isid circle_id
tempfile pilot_circles
sa `pilot_circles'

* Load treatment list for Year 1
use "TP Analysis/Coded Data/Randomization Year 1", clear
keep circle_id hr_id
gen treatment_y1 = 1
merge 1:1 circle_id using `pilot_circles', keep(1) nogen // Remove circles used in pilot
keep hr_id treatment_y1
isid hr_id
tempfile y1_treat_inspectors
sa `y1_treat_inspectors'

* Add year 2 treatment status
use "Data\Randomization\Ballot Cleaning Year 2\Output/Complete Treatment List Year 2.dta", clear
keep hr_id
duplicates drop
gen treatment_y2 = 1
merge m:1 hr_id using `y1_treat_inspectors', keep(2 3) nogen
replace treatment_y2 = 0 if mi(treatment_y2)
replace treatment_y1 = 0 if mi(treatment_y1)
gen continuing = treatment_y2 & treatment_y1
sa `y1_treat_inspectors', replace

* Need to crosswalk transfer table circle IDs
insheet using "Data/Raw Data/Administrative Data/120904 Crosswalk to Randomization_All.csv", comma clear
keep ballot_circle_id
duplicates drop
drop if mi(ballot_circle_id)
tempfile ballot_circle_ids
sa `ballot_circle_ids', replace

* Load and compile preference data
	clear all
	* List of files in directory
	local pref_files : dir "Data\Raw Data\Preference Tracking\Data/" files "*.xlsx"
	* Create empty file for Y1 preferences
	tempfile y1_preferences
	save `y1_preferences', emptyok
	* Append all files in directory
	foreach file in `pref_files' { 
		import excel using "Data\Raw Data\Preference Tracking/Data/`file'", firstrow clear
		destring own_circle, replace // is string in some files, byte in others
		append using `y1_preferences'
		sa `y1_preferences', replace
	}
	ren K comments
	* Create accurate group IDs
	replace division_name = "LAHORE" if inlist(division_name, "LAHORE A", "LAHORE B")
	egen group_id = group(division_name group)
	* Ensure rankings make sense
	bys own_hr_id: egen rank_sum = total(ranking)
	bys own_hr_id: egen rank_count = count(ranking)
	assert rank_sum == (rank_count * (rank_count + 1))/2 if rank_count > 0
	drop rank_sum rank_count
	* Normalize all rankings
	bys own_hr_id: egen rank_count = count(ranking)
	bys own_hr_id: egen max_rank = max(ranking)
	assert max_rank == rank_count if rank_count > 0
	*replace ranking = 1 + ( ((ranking-1)/(rank_count-1)) * (10-1) ) if rank_count > 0
	drop rank_count max_rank
	sa `y1_preferences', replace
	* Load Baseline preference data for treatment inspectors
	use "TP Analysis/Coded Data/Treatment Baseline Preferences for Analysis complete OLD", clear
	merge m:1 circle_id using `pilot_circles' // Remove pilot circles
	keep if _m == 1
	drop _m
	ren hr_id own_hr_id
	drop if mi(own_hr_id)
	drop if own_hr_id==11507 & group==4 // additional charge
	drop if own_hr_id==40962 & group==1
	* Ensure rankings make sense
	bys own_hr_id group: egen rank_sum = total(ranking)
	bys own_hr_id group: egen rank_count = count(ranking)
	assert rank_sum == (rank_count * (rank_count + 1))/2 if rank_count > 0
	drop rank_sum rank_count
	* Normalize all rankings
	bys own_hr_id group: egen rank_count = count(ranking)
	bys own_hr_id group: egen max_rank = max(ranking)
	assert max_rank == rank_count if rank_count > 0
	*replace ranking = 1 + ( ((ranking-1)/(rank_count-1)) * (10-1) ) if rank_count > 0
	drop rank_count max_rank
	tempfile base_preferences
	sa `base_preferences'

* Load and compile transfer tables

	clear all
	* List of files in directory
	local pref_files : dir "Data\Raw Data\FY 14 Transfers/Transfer Tables FULL/" files "140823*.xlsx"
	* Create empty file for Y1 preferences
	tempfile transfer_table
	save `transfer_table', emptyok
	* Append all files in directory
	foreach file in `pref_files' { 
		import excel using "Data\Raw Data\FY 14 Transfers/Transfer Tables FULL/`file'", firstrow clear
		append using `transfer_table'
		sa `transfer_table', replace
	}
	*drop if O=="DROPPED"
	keep HRID BallotedCircle NewCircle
	ren (HRID BallotedCircle NewCircle) (hr_id current_circle_id new_circle_id)
	sa `transfer_table', replace
	* Identify current circles that need to be crosswalked
	use `ballot_circle_ids', clear
	ren ballot_circle_id current_circle_id
	merge 1:m current_circle using `transfer_table', keep(2 3)
	gen current_circle_crosswalked = (_m == 2) if !mi(current_circle_id)
	drop _m
	sa `transfer_table', replace
	* Identify new circles that need to be crosswalked (none, it turns out!)
	use `ballot_circle_ids', clear
	ren ballot_circle_id new_circle_id
	merge 1:m new_circle_id using `transfer_table', keep(2 3)
	gen new_circle_crosswalked = (_m == 2) if !mi(new_circle_id)
	drop _m
	* Manually crosswalk current circles
	replace current_circle_id = 507201 if current_circle_id == 507300
	replace current_circle_id = 613610 if current_circle_id == 613630
	replace current_circle_id = 614300 if current_circle_id == 614310
	replace current_circle_id = 807101 if current_circle_id == 807103
	replace current_circle_id = 807102 if current_circle_id == 807104
	replace current_circle_id = . 	   if current_circle_id == 907900
	drop *crosswalked
	drop if mi(current_circle_id)
	sa `transfer_table', replace

* Add rank of new and current circle using baseline preferences

	* Ranking for current circle
	use `base_preferences', clear
	drop if mi(ranking)
	duplicates drop
	* Count the number of distinct inspectors in each group
	preserve
		keep partition_name group own_hr_id
		duplicates drop
		collapse (count) own_hr_id, by(partition_name group)
		ren own_hr_id num_ins_in_group
		tempfile num_ins_per_group
		sa `num_ins_per_group', replace
	restore
	merge m:1 partition_name group using `num_ins_per_group', assert(match) keepusing(num_ins_in_group) nogen
	* Calculate u1
	bys partition_name group own_hr_id (ranking): gen simple_rank = _n
	gen u1 = 1 - ( (simple_rank-1) / (num_ins_in_group - 1) )
	replace u1 = 0 if u1 < 0
	keep own_hr_id circle_id ranking u1
	duplicates drop
	ren own_hr_id hr_id
	ren ranking base_current_ranking
	ren circle_id current_circle_id
	ren u1 base_current_u1
	merge 1:1 current_circle_id hr_id using `transfer_table', keep(2 3) nogen
	tempfile pref_analysis_data
	sa `pref_analysis_data'
	* Ranking for new circle
	use `base_preferences', clear
	keep own_hr_id circle_id ranking
	drop if mi(ranking)
	duplicates drop
	ren own_hr_id hr_id
	ren ranking base_new_ranking
	ren circle_id new_circle_id
	merge 1:1 new_circle_id hr_id using `pref_analysis_data', keep(2 3) nogen
	tempfile pref_analysis_data
	sa `pref_analysis_data'

* Add rank of new and current circle using y1 preferences (also calculate u1 of current)
	
	* Ranking for current circle
	use `y1_preferences', clear
	drop if mi(ranking)
	duplicates drop
	* Count the number of distinct inspectors in each group
	preserve
		keep division_name group_id own_hr_id
		duplicates drop
		collapse (count) own_hr_id, by(division_name group_id)
		ren own_hr_id num_ins_in_group
		tempfile num_ins_per_group
		sa `num_ins_per_group', replace
	restore
	merge m:1 division_name group_id using `num_ins_per_group', assert(match) keepusing(num_ins_in_group) nogen
	* Calculate u1
	bys division_name group own_hr_id (ranking): gen simple_rank = _n
	gen u1 = 1 - ( (simple_rank-1) / (num_ins_in_group - 1) )
	replace u1 = 0 if u1 < 0
	keep own_hr_id circle_id ranking u1
	duplicates drop
	ren own_hr_id hr_id
	ren ranking y1_current_ranking
	ren circle_id current_circle_id
	ren u1 y1_current_u1
	merge 1:1 current_circle_id hr_id using `pref_analysis_data', keep(2 3) nogen
	sa `pref_analysis_data', replace
	* Ranking for new circle
	use `y1_preferences', clear
	keep own_hr_id circle_id ranking
	drop if mi(ranking)
	duplicates drop
	ren own_hr_id hr_id
	ren ranking y1_new_ranking
	ren circle_id new_circle_id
	merge 1:1 new_circle_id hr_id using `pref_analysis_data', keep(2 3) nogen
	sa `pref_analysis_data', replace

* Figure out the top choice for each inspectors, and add to analysis dataset

	use `y1_preferences', clear
	keep if ranking == 1
	duplicates drop
	keep own_hr_id circle_id
	ren own_hr_id hr_id
	ren circle_id y1_top_choice
	merge 1:1 hr_id using `pref_analysis_data', keep(match) nogen
	sa `pref_analysis_data', replace
	use `base_preferences', clear
	keep if ranking == 1
	duplicates drop
	keep own_hr_id circle_id
	ren own_hr_id hr_id
	ren circle_id base_top_choice
	merge 1:1 hr_id using `pref_analysis_data', keep(2 3) nogen
	sa `pref_analysis_data', replace

* Calculate rank correlation 

	* First, put rankings side by side
	use `y1_preferences', clear
	keep own_hr_id circle_id ranking
	drop if mi(ranking)
	ren ranking y1_ranking
	ren own_hr_id hr_id
	drop if circle_id == 402800 // see notes in header for why we need to do this
	tempfile y1_preferences_concise
	sa `y1_preferences_concise'
	use `base_preferences', clear
	keep own_hr_id circle_id ranking
	drop if mi(ranking)
	ren ranking base_ranking
	ren own_hr_id hr_id
	drop if circle_id == 402700 // see notes in header for why we need to do this
	merge 1:1 hr_id circle_id using `y1_preferences_concise', keep(match) nogen
	* Second, compute spearman's rho
	statsby rank_corr = r(rho), by(hr_id) clear : spearman y1_ranking base_ranking
	* Lastly, save
	merge 1:1 hr_id using `pref_analysis_data', keep(2 3) nogen
	sa `pref_analysis_data', replace

* Create group identifier

	use `y1_preferences', clear

	* Drop cases where inspector has missing preferences, when he already has preferences for another group.
	bys own_hr_id group_id: egen num_not_missing = count(ranking)
	bys own_hr_id group_id: gen any_missing = num_not_missing != _N
	keep own_hr_id group_id any_missing
	duplicates drop
	bys own_hr_id: drop if any_missing & _N > 1
	ren own_hr_id hr_id
	isid hr_id
	merge 1:1 hr_id using `pref_analysis_data', keep(2 3) nogen
	assert !mi(group_id)
	sa `pref_analysis_data', replace

************************************************************************************************************************
* Create variables, final merge
************************************************************************************************************************

* Generate analysis variables

	use `pref_analysis_data', clear
	gen move_up_base = 				base_new_ranking < base_current_ranking 	if !mi(base_new_ranking) & !mi(base_current_ranking)
	gen move_down_base = 			base_new_ranking > base_current_ranking		if !mi(base_new_ranking) & !mi(base_current_ranking)
	gen move_up_y1 = 				y1_new_ranking < y1_current_ranking			if !mi(y1_new_ranking) & !mi(y1_current_ranking)
	gen move_down_y1 = 				y1_new_ranking > y1_current_ranking			if !mi(y1_new_ranking) & !mi(y1_current_ranking)
	gen any_move =					new_circle_id != current_circle_id			if !mi(new_circle_id)
	gen own_circle_favorite = 		y1_current_ranking == 1						if !mi(y1_current_ranking)
	gen own_circle_favorite_base = 	base_current_ranking == 1					if !mi(base_current_ranking)
	gen own_circle_rank = 			y1_current_ranking							if !mi(y1_current_ranking)			
	gen own_circle_rank_base = 		base_current_ranking						if !mi(base_current_ranking)
	gen own_circle_u1 = 			y1_current_u1								if !mi(y1_current_u1)			
	gen own_circle_u1_base = 		base_current_u1								if !mi(base_current_u1)

	merge 1:1 hr_id using `y1_treat_inspectors', assert(2 3)  nogen

	label var continuing 				"Continuing"
	label var own_circle_rank_base 		"Own circle rank, baseline"
	label var own_circle_favorite_base 	"Own circle is favorite, baseline"
	label var own_circle_u1 			"Own circle u1"
	label var own_circle_u1_base 		"Own circle u1, baseline"

	* Add: is first choice the same in Y1 and base?
	gen top_choice_same = base_top_choice == y1_top_choice if !mi(base_top_choice) & !mi(y1_top_choice)
	tempfile y1pref_analysis
	sa `y1pref_analysis'

* Performance by inspector

	use "TP Analysis\Coded Data/Q4 Ranks", clear
	rename (rank ranking_method) (rank_perf ranking_method_perf)
	tempfile y1_performance
	save `y1_performance'

* Merge performance with preferences

	use "`y1pref_analysis'", clear
	drop move* own_circle_favorite_base own_circle_favorite
	gen move_up_base = 				base_new_ranking < base_current_ranking 	if !mi(base_new_ranking) & !mi(base_current_ranking)
	gen move_down_base = 			base_new_ranking > base_current_ranking		if !mi(base_new_ranking) & !mi(base_current_ranking)
	gen move_up_y1 = 				y1_new_ranking < y1_current_ranking			if !mi(y1_new_ranking) & !mi(y1_current_ranking)
	gen move_down_y1 = 				y1_new_ranking > y1_current_ranking			if !mi(y1_new_ranking) & !mi(y1_current_ranking)
	gen own_circle_favorite_base = 	(base_current_ranking == 1 & !mi(base_current_ranking)) | (base_current_ranking == 2 & !mi(base_current_ranking))
	gen own_circle_favorite = 		(y1_current_ranking == 1 & !mi(y1_current_ranking)) | (y1_current_ranking == 2 	& !mi(y1_current_ranking))
	gen change_ranking_base = base_new_ranking - base_current_ranking if !mi(base_new_ranking) & !mi(base_current_ranking)
	gen change_ranking_y1 = y1_new_ranking - y1_current_ranking if !mi(y1_new_ranking) & !mi(y1_current_ranking)
	merge 1:1 hr_id using `y1_performance', keep(match) keepusing(final_score *perf)
	rename final_score performance_recov_y1

	gsort group_id -performance_recov_y1
	by group_id: gen rank_y1 = _n
	summ rank_y1 , meanonly
	gen norm_rank_y1=(r(max)-rank_y1)/(r(max)-r(min))
	label var performance_recov_y1 "Y1 Performance"
	label var rank_y1 "Y1 Rank"

	foreach var in base_new_ranking base_current_ranking y1_new_ranking y1_current_ranking {
	gen norm_`var' = (10-`var')/9
	}
	gen norm_change_ranking_base = norm_base_new_ranking - norm_base_current_ranking if !mi(base_new_ranking) & !mi(base_current_ranking)
	gen norm_change_ranking_y1 = norm_y1_new_ranking - norm_y1_current_ranking if !mi(y1_new_ranking) & !mi(y1_current_ranking)

	summ rank_perf
	replace rank_perf=(r(max)-rank_perf)/(r(max)-r(min))
	gen demand=ranking_method_perf=="DEMAND"
	label var rank_perf "Y1 Performance rank"

save "TP Analysis/Coded Data/Preferences data - treatment", replace
