/*

Basic treatment effect for Years 1 and 2; RI p-values.

*/

*************************************************************
* Initial Setup
*************************************************************

clear all
set mem 400m
set more off
pause on
set maxvar 32767
cap cd "${TP_ANALYSIS}"
do "Do Files/programs/all_programs.do"

*************************************************************
* Define a program for storing p values from Rand Inference
*************************************************************

cap prog drop add_pval 
program define add_pval, eclass // Name of the command
syntax,  results(string) pval(real) indvar(string) // Associate p with estimates of y, local pval and indep variable indvar.

estimates restore `results'

matrix pval=J(1,1,.) // Opens a space for pvalue
matrix colnames pval="`indvar'" 

matrix pval[1,1]=`pval' // Defines where the value comes from

estadd matrix pval pval // Stores the matrix

end

************************************************************* 
* Prepare datasets
*************************************************************

* Load Y1 data (to be used as baseline in some regressions)
use "Coded Data/150525 TP Analysis Data FULL SAMPLE", clear
keep circle_id qtr ln_gross_* ln_net_* ln_recov_*
foreach var in recov_tot net_dem gross_dem {
	foreach x in c a t {
		ren ln_`var'_`x' y1_ln_`var'_`x'
	}
}

* Load and temporarily save Y2 data
merge 1:1 circle_id qtr using "Coded Data/TP Y2 Analysis Data w Y1 Treatment", keep(match)
drop if litigated == 1 // drop litigated circles
keep if qtr == 4
drop if treatment_y1 == 1
gen y1 = 0
ren (DEM_sel REV_sel treatment) (DEM_sel_y2 REV_sel_y2 treatment_y2)
label var treatment_y2 "Treatment"
label var DEM_sel_y2 "Demand"
label var REV_sel_y2 "Revenue"
ren treatment_y2 treatment
gen baseline= .
label var baseline "Baseline"
tempfile y2_data_more
sa `y2_data_more'
drop if mi(treatment_y1)
tempfile y2_data
sa `y2_data'

* Load and temporarily save Y1 data
use "Coded Data/150525 TP Analysis Data", clear
drop if litigated == 1
keep if qtr == 4
merge 1:1 circle_id using "Coded Data/Y2 Q1 Demand", assert(2 3) keep(match) keepusing(ln*) nogen
foreach x in t c a {
	foreach d in net_dem gross_dem {
		replace ln_`d'_`x' = ln_y2q1_`d'_`x' // Replace Y1 Q4 Demand values with Y2 Q1 Demand values (because that is when Demand is updated).
	}
}
drop *y2q1*
gen y1 = 1
gen baseline = .
ren (DEM_sel REV_sel treatment) (DEM_sel_y1 REV_sel_y1 treatment_y1)
label var treatment_y1 "Treatment"
label var DEM_sel_y1 "Demand"
label var REV_sel_y1 "Revenue"
label var baseline "Baseline"
ren treatment_y1 treatment
label var baseline "Baseline"
tempfile y1_data
sa `y1_data'

* Create pooled dataset
use `y1_data', clear
append using `y2_data'
gen base_y1_interact= .
gen pre = .
forval i = 1/33 {
	gen stratdum_y1_interact`i' = y1 * stratdum`i'
	replace stratdum`i' = 0 if mi(stratdum`i')
	replace stratdum_y1_interact`i' = 0 if mi(stratdum_y1_interact`i')
}
tempfile pooled_data
sa `pooled_data'

* Create pooled dataset, Appendix
use `y1_data', clear
append using `y2_data_more'
gen base_y1_interact = .
gen pre = .
forval i = 1/33 {
	gen stratdum_y1_interact`i' = y1 * stratdum`i'
	replace stratdum`i' = 0 if mi(stratdum`i')
	replace stratdum_y1_interact`i' = 0 if mi(stratdum_y1_interact`i')
}
tempfile pooled_data_more
sa `pooled_data_more'

*************************************************************
* Prepare datasets II: randomization files
*************************************************************

local num 2000

quietly{
forval m = 1/`num' {

* Load Y1 data (to be used as baseline in some regressions)

use "Coded Data/150525 TP Analysis Data FULL SAMPLE", clear
keep circle_id qtr ln_gross_* ln_net_* ln_recov_*
foreach var in recov_tot net_dem gross_dem {
	foreach x in c a t {
		ren ln_`var'_`x' y1_ln_`var'_`x'
	}
}

* Load and temporarily save Y2 data
merge 1:1 circle_id qtr using "Coded Data/TP Y2 Analysis Data w Y1 Treatment", keep(match) nogen
drop if litigated == 1 // drop litigated circles
keep if qtr == 4
drop treatment* group_id
merge 1:1 circle_id using "Coded Data/RI/rand_code_iter", keepusing(treatment_y1_`m'  treatment_y2_`m' DEM_sel_y2_`m' REV_sel_y2_`m' group_id_`m') 
rename (treatment_y1_`m' group_id_`m' treatment_y2_`m' DEM_sel_y2_`m' REV_sel_y2_`m') (treatment_y1  group_id treatment_y2 DEM_sel_y2 REV_sel_y2 )
drop if treatment_y1 == 1
gen y1 = 0
label var treatment_y2 "Treatment"
label var DEM_sel_y2 "Demand"
label var REV_sel_y2 "Revenue"
ren treatment_y2 treatment
gen baseline= .
label var treatment "Treatment"
rename treatment treatment_`m'
tempfile y2_data_more_`m'
sa `y2_data_more_`m''
drop if mi(treatment_y1)
tempfile y2_data_`m'
sa `y2_data_`m''

* Load and temporarily save Y1 data
use "Coded Data/150525 TP Analysis Data", clear
drop if litigated == 1
keep if qtr == 4
merge 1:1 circle_id using "Coded Data/Y2 Q1 Demand", assert(2 3) keep(match) keepusing(ln*) nogen
foreach x in t c a {
	foreach d in net_dem gross_dem {
		replace ln_`d'_`x' = ln_y2q1_`d'_`x' // Replace Y1 Q4 Demand values with Y2 Q1 Demand values (because that is when Demand is updated).
	}
}
drop *y2q1*
gen y1 = 1
gen baseline = .
drop treatment* group_id DEM_sel*  REV_sel*
merge 1:1 circle_id using "Coded Data/RI/rand_code_iter", keepusing(treatment_y1_`m'  DEM_sel_y1_`m' REV_sel_y1_`m' group_id_`m') 
rename (treatment_y1_`m' group_id_`m' DEM_sel_y1_`m' REV_sel_y1_`m') (treatment_y1  group_id DEM_sel_y1 REV_sel_y1 )
label var treatment_y1 "Treatment"
label var DEM_sel_y1 "Demand"
label var REV_sel_y1 "Revenue"
*label var baseline "Baseline"
ren treatment_y1 treatment
label var treatment "Treatment"
rename (treatment DEM_sel_y1 REV_sel_y1) (treatment_`m' DEM_sel_y1_`m' REV_sel_y1_`m')
tempfile y1_data_`m'
sa `y1_data_`m''

* Create pooled dataset
use `y1_data_`m'', clear
append using `y2_data_`m''
gen base_y1_interact = .
forval z = 1/33 {
	gen stratdum_y1_interact`z' = y1 * stratdum`z'
	replace stratdum`z' = 0 if mi(stratdum`z')
	replace stratdum_y1_interact`z' = 0 if mi(stratdum_y1_interact`z')
}
tempfile pooled_data_`m'
sa `pooled_data_`m''

* Create pooled dataset for second Y2 sample
use `y1_data_`m'', clear
append using `y2_data_more_`m''
gen base_y1_interact = .
forval z = 1/33 {
	gen stratdum_y1_interact`z' = y1 * stratdum`z'
	replace stratdum`z' = 0 if mi(stratdum`z')
	replace stratdum_y1_interact`z' = 0 if mi(stratdum_y1_interact`z')
}
tempfile pooled_data_more_`m'
sa `pooled_data_more_`m''

}
}

*************************************************************
* Run regressions
*************************************************************

forval z = 1/1 { 
			
	local var : word `z' of recov_tot net_dem gross_dem	
	local w1 : word `z' of "Recovery" "Net Demand" "Gross Demand"
	local w2 : word `z' of "recovery" "net demand" "gross demand"
	local y1_title : word `z' of "Year 1 (Y1 Q4)" "Year 1 (Y2 Q1)" "Year 1 (Y2 Q1)"
	local y2_title : word `z' of "Year 2 (Y2 Q4)" "Year 2 (Y2 Q4)" "Year 2 (Y2 Q4)"
	
	local file basic_treatment_effect_`var'

	* Y1 outcomes
	
	foreach x in c a t {
	
		quietly{ 
		
		tempname y1_data_rand_inf_`x'
		postfile `y1_data_rand_inf_`x'' b s using y1_data_rand_inf_`x'.dta, replace 
		forval m = 1/`num' {
		use `y1_data_`m'', clear
		replace baseline = base_ln_`var'_`x'
		reg ln_`var'_`x' treatment_`m' baseline, cluster(circle_id)
		post `y1_data_rand_inf_`x'' (_b[treatment_`m']) (_se[treatment_`m'])
		}
		postclose `y1_data_rand_inf_`x''
		
		use `y1_data', clear
		replace baseline = base_ln_`var'_`x'
		eststo y1_`x'_no_sfe : reg ln_`var'_`x' treatment baseline, cluster(circle_id)
		qui sum ln_`var'_`x' if e(sample) == 1 & treatment == 0
		scalar ymean1 = `r(mean)'		
		estadd scalar ymean1 = `r(mean)'		
		qui sum baseline if e(sample) == 1 & treatment == 0
		scalar ymean0 = `r(mean)'
		estadd scalar ymean0 = `r(mean)'
		scalar ymean=`=ymean1'-`=ymean0'
		estadd scalar ymean=`=ymean1'-`=ymean0'
		scalar breg = _b[treatment]
		estadd scalar breg = _b[treatment]
		eststo y1_`x'_no_sfe
		
		}
		
		use y1_data_rand_inf_`x'.dta, clear // Comparing b from baseline reg with others
		gen t = abs(b/s) 
		preserve
		keep if abs(b)> abs(`=breg')
		if _N==0{
			local b_p= 0.001
			}
		else {
			local b_p = _N / `num' 
			}
		display `b_p'
		restore
		add_pval, results(y1_`x'_no_sfe) pval(`b_p') indvar(treatment) // From the program above
		eststo y1_`x'_no_sfe
		erase y1_data_rand_inf_`x'.dta
		
		}

	* Y2 outcomes

	foreach x in c a t {
	
		quietly{ // Regressions for randomized treatments
		
		tempname y2_data_rand_inf_`x'
		postfile `y2_data_rand_inf_`x'' b s using y2_data_rand_inf_`x'.dta, replace 
		forval m = 1/`num' {
		use `y2_data_`m'', clear
		replace baseline = base_ln_`var'_`x'
		reg ln_`var'_`x' treatment_`m' baseline, cluster(circle_id)
		post `y2_data_rand_inf_`x'' (_b[treatment_`m']) (_se[treatment_`m'])
		}
		postclose `y2_data_rand_inf_`x''

		use `y2_data', clear
		replace baseline = base_ln_`var'_`x'
		eststo y2_`x'_no_sfe : reg ln_`var'_`x' treatment baseline, cluster(circle_id)
		qui sum ln_`var'_`x' if e(sample) == 1 & treatment == 0
		scalar ymean1 = `r(mean)'		
		estadd scalar ymean1 = `r(mean)'		
		qui sum y1_ln_`var'_`x' if e(sample) == 1 & treatment == 0
		scalar ymean0 = `r(mean)'
		estadd scalar ymean0 = `r(mean)'
		scalar ymean=`=ymean1'-`=ymean0'
		estadd scalar ymean=`=ymean1'-`=ymean0'
		scalar breg = _b[treatment]
		estadd scalar breg = _b[treatment]
		eststo y2_`x'_no_sfe
		
		}
		
		use y2_data_rand_inf_`x'.dta, clear // Comparing b from baseline reg with others
		gen t = abs(b/s) 
		preserve
		keep if abs(b)> abs(`=breg')
		if _N==0{
			local b_p= 0.001
			}
		else {
			local b_p = _N / `num' 
			}
		display `b_p'
		restore
		add_pval, results(y2_`x'_no_sfe) pval(`b_p') indvar(treatment) // From the program above
		eststo y2_`x'_no_sfe
		erase y2_data_rand_inf_`x'.dta
		
		}	
	
	* Pooled outcomes
	
	foreach x in c a t {
		
		quietly{ 
		
		tempname pooled_data_rand_inf_`x'
		postfile `pooled_data_rand_inf_`x'' b s using pooled_data_rand_inf_`x'.dta, replace 
		forval m = 1/`num' {
		use `pooled_data_`m'', clear
		replace baseline = base_ln_`var'_`x'
		replace base_y1_interact = y1 * baseline
		reg ln_`var'_`x' treatment_`m' baseline base_y1_interact y1, cluster(circle_id)
		post `pooled_data_rand_inf_`x'' (_b[treatment_`m']) (_se[treatment_`m'])
		}
		postclose `pooled_data_rand_inf_`x''
	
		use `pooled_data', clear
		replace baseline = base_ln_`var'_`x'
		replace pre=base_ln_`var'_`x' if y1==1
		replace pre=y1_ln_`var'_`x' if y1==0
		replace base_y1_interact = y1 * baseline

		eststo pooled_`x'_no_sfe : reg ln_`var'_`x' treatment baseline base_y1_interact y1, cluster(circle_id)
		qui sum ln_`var'_`x' if e(sample) == 1 & treatment == 0
		scalar ymean1 = `r(mean)'		
		estadd scalar ymean1 = `r(mean)'		
		qui sum pre if e(sample) == 1 & treatment == 0
		scalar ymean0 = `r(mean)'
		estadd scalar ymean0 = `r(mean)'
		scalar ymean=`=ymean1'-`=ymean0'
		estadd scalar ymean=`=ymean1'-`=ymean0'
		scalar breg = _b[treatment]
		estadd scalar breg = _b[treatment]
		eststo pooled_`x'_no_sfe
		
		}
		
		use pooled_data_rand_inf_`x'.dta, clear // Comparing b from baseline reg with others
		gen t = abs(b/s) 
		preserve
		keep if abs(b)> abs(`=breg')
		if _N==0{
			local b_p= 0.001
			}
		else {
			local b_p = _N / `num' 
			}
		display `b_p'
		restore
		add_pval, results(pooled_`x'_no_sfe) pval(`b_p') indvar(treatment) // From the program above
		eststo pooled_`x'_no_sfe
		erase pooled_data_rand_inf_`x'.dta
		
		}

*************************************************************
* Draw tables
*************************************************************
	
	local file basic_treatment_effect_`var'_rand
	
	# delimit ;
	esttab y1_t_no_sfe y1_c_no_sfe y1_a_no_sfe y2_t_no_sfe y2_c_no_sfe y2_a_no_sfe pooled_t_no_sfe pooled_c_no_sfe pooled_a_no_sfe
		using "${TP_PAPER_OUTPUT}/tex/input/`file'_input.tex", 
		keep(treatment baseline)
		order(treatment baseline)
		cells(b(fmt(%12.3f))
		      se(fmt(%12.3f) par)
			  pval(fmt(%12.3f) par([ ]))
			 )
		coeflabels(treatment "Treatment" baseline "Baseline")
		collabels(none)		
		stardrop(treatment)
		
		mtitles("Total" "Current" "Arrears" "Total" "Current" "Arrears" "Total" "Current" "Arrears") // Column headings
		
		stats(N  ymean,
			labels(
				"N"
				"Mean growth in controls"
				)	
			fmt(
				"%12.0f" "%12.3f"
			)
			layout("@" "@")
		)	
		
		mgroups("`y1_title'" "`y2_title'" "Pooled",
			pattern(1 0 0 1 0 0 1 0 0)
			prefix(\multicolumn{@span}{c}{)
			suffix(}) span erepeat(\cmidrule(lr){@span})
		)		
		
		label // Use Variable Labels
		booktabs // a nicer version of tables
		substitute("<" "$<$")
		fragment
		// append
		replace
		;

	# delimit cr

	** WRITE LaTeX WRAPPER AND COMPILE TO PDF **************************************

	set more off

	** WRITE TABLE NOTE

	file open tablenote using "${TP_PAPER_OUTPUT}/tex/notes/`file'_notes.txt", write replace

	file write tablenote "Tax revenue (columns 1, 4, and 7) is comprised of revenue from the current years tax due (columns 2, 5, and 8),"
	file write tablenote " plus revenue collected from previous years' unpaid taxes (denoted 'arrears', columns 3, 6, and 9);"
	file write tablenote " the dependent variable in each column is the log of the respective tax measure."
	file write tablenote " Estimation is by OLS. The unit of observation is a circle, as defined at the time of randomization."
	file write tablenote " Specification controls for baseline values (FY 2013). Robust standard errors in parentheses."
	file write tablenote " Standard errors are clustered by circle. Randomization inference based p-values in brackets."

	file close tablenote

	texout2 "${TP_PAPER_OUTPUT}/tex/`file'", ///
	  input("input/`file'_input") notes("notes/`file'_notes")

	compiletex "${TP_PAPER_OUTPUT}/tex/`file'.tex", ///
	  out("..") aux("auxdir/")  
	
di "DONE!"



*************************************************************
* Run regressions and Draw tables, Appendix
*************************************************************

	* Y2 outcomes, Appendix

	foreach x in c a t {
	
		quietly{ 
		
		tempname y2_data_rand_inf_more_`x'
		postfile `y2_data_rand_inf_more_`x'' b s using y2_data_rand_inf_more_`x'.dta, replace 
		forval m = 1/`num' {
		use `y2_data_more_`m'', clear
		replace baseline = base_ln_`var'_`x'
		reg ln_`var'_`x' treatment_`m' baseline, cluster(circle_id)
		post `y2_data_rand_inf_more_`x'' (_b[treatment_`m']) (_se[treatment_`m'])
		}
		postclose `y2_data_rand_inf_more_`x''

		use `y2_data_more', clear
		replace baseline = base_ln_`var'_`x'
		eststo y2_`x'_no_sfe : reg ln_`var'_`x' treatment baseline, cluster(circle_id)
		qui sum ln_`var'_`x' if e(sample) == 1 & treatment == 0
		scalar ymean1 = `r(mean)'		
		estadd scalar ymean1 = `r(mean)'		
		qui sum y1_ln_`var'_`x' if e(sample) == 1 & treatment == 0
		scalar ymean0 = `r(mean)'
		estadd scalar ymean0 = `r(mean)'
		scalar ymean=`=ymean1'-`=ymean0'
		estadd scalar ymean=`=ymean1'-`=ymean0'
		scalar breg = _b[treatment]
		estadd scalar breg = _b[treatment]
		eststo y2_`x'_no_sfe
		
		}
		
		use y2_data_rand_inf_more_`x'.dta, clear // Comparing b from baseline reg with others
		gen t = abs(b/s) 
		preserve
		keep if abs(b)> abs(`=breg')
		if _N==0{
			local b_p= 0.001
			}
		else {
			local b_p = _N / `num' 
			}
		display `b_p'
		restore
		add_pval, results(y2_`x'_no_sfe) pval(`b_p') indvar(treatment) // From the program above
		eststo y2_`x'_no_sfe
		erase y2_data_rand_inf_more_`x'.dta
		
		}
	
	* Pooled outcomes, Appendix
	
	foreach x in c a t {
		
		quietly{ 
		
		tempname pooled_data_rand_inf_more_`x'
		postfile `pooled_data_rand_inf_more_`x'' b s using pooled_data_rand_inf_more_`x'.dta, replace 
		forval m = 1/`num' {
		use `pooled_data_more_`m'', clear
		replace baseline = base_ln_`var'_`x'
		replace base_y1_interact = y1 * baseline
		reg ln_`var'_`x' treatment_`m' baseline base_y1_interact y1, cluster(circle_id)
		post `pooled_data_rand_inf_more_`x'' (_b[treatment_`m']) (_se[treatment_`m'])
		}
		postclose `pooled_data_rand_inf_more_`x''
	
		use `pooled_data_more', clear
		replace baseline = base_ln_`var'_`x'
		replace pre=base_ln_`var'_`x' if y1==1
		replace pre=y1_ln_`var'_`x' if y1==0
		replace base_y1_interact = y1 * baseline
		eststo pooled_`x'_no_sfe : reg ln_`var'_`x' treatment baseline base_y1_interact y1, cluster(circle_id)
		qui sum ln_`var'_`x' if e(sample) == 1 & treatment == 0
		scalar ymean1 = `r(mean)'		
		estadd scalar ymean1 = `r(mean)'		
		qui sum pre if e(sample) == 1 & treatment == 0
		scalar ymean0 = `r(mean)'
		estadd scalar ymean0 = `r(mean)'
		scalar ymean=`=ymean1'-`=ymean0'
		estadd scalar ymean=`=ymean1'-`=ymean0'
		scalar breg = _b[treatment]
		estadd scalar breg = _b[treatment]
		eststo pooled_`x'_no_sfe
		
		}
		
		use pooled_data_rand_inf_more_`x'.dta, clear // Comparing b from baseline reg with others
		gen t = abs(b/s) 
		preserve
		keep if abs(b)> abs(`=breg')
		if _N==0{
			local b_p= 0.001
			}
		else {
			local b_p = _N / `num' 
			}
		display `b_p'
		restore
		add_pval, results(pooled_`x'_no_sfe) pval(`b_p') indvar(treatment) // From the program above
		eststo pooled_`x'_no_sfe
		erase pooled_data_rand_inf_more_`x'.dta
		
		}
		
	local file2 basic_treatment_effect_`var'_rand_include_more_y2
	
	* FY 2013 as baseline
	# delimit ;
	esttab y1_t_no_sfe y1_c_no_sfe y1_a_no_sfe y2_t_no_sfe y2_c_no_sfe y2_a_no_sfe pooled_t_no_sfe pooled_c_no_sfe pooled_a_no_sfe
		using "${TP_PAPER_OUTPUT}/tex/input/`file2'_input.tex", 
		keep(treatment baseline)
		order(treatment baseline)
		cells(b(fmt(%12.3f))
		      se(fmt(%12.3f) par)
			  pval(fmt(%12.3f) par([ ]))
			 )
		coeflabels(treatment "Treatment" baseline "Baseline")
		collabels(none)		
		stardrop(treatment)
		
		mtitles("Total" "Current" "Arrears" "Total" "Current" "Arrears" "Total" "Current" "Arrears") // Column headings
		
		stats(N ymean,
			labels(
				"N"
				"Mean growth in controls"
			)	
			fmt(
				"%12.0f" "%12.3f"
			)
			layout("@" "@")
		)	
		
		mgroups("`y1_title'" "`y2_title'" "Pooled",
			pattern(1 0 0 1 0 0 1 0 0)
			prefix(\multicolumn{@span}{c}{)
			suffix(}) span erepeat(\cmidrule(lr){@span})
		)		
		
		label // Use Variable Labels
		booktabs // a nicer version of tables
		substitute("<" "$<$")
		fragment
		// append
		replace
		;

	# delimit cr

	** WRITE LaTeX WRAPPER AND COMPILE TO PDF **************************************

	set more off

	** WRITE TABLE NOTE

	file open tablenote using "${TP_PAPER_OUTPUT}/tex/notes/`file2'_notes.txt", write replace

	file write tablenote "Tax revenue (columns 1, 4, and 7) is comprised of revenue from the current years tax due (columns 2, 5, and 8),"
	file write tablenote " plus revenue collected from previous years' unpaid taxes (denoted 'arrears', columns 3, 6, and 9);"
	file write tablenote " the dependent variable in each column is the log of the respective tax measure."
	file write tablenote " Estimation is by OLS. The unit of observation is a circle, as defined at the time of randomization."
	file write tablenote " Specification controls for baseline values (FY 2013). Robust standard errors in parentheses."
	file write tablenote " Standard errors are clustered by circle. Randomization inference based p-values in brackets."

	file close tablenote

	texout2 "${TP_PAPER_OUTPUT}/tex/`file2'", ///
	  input("input/`file2'_input") notes("notes/`file2'_notes")

	compiletex "${TP_PAPER_OUTPUT}/tex/`file2'.tex", ///
	  out("..") aux("auxdir/")   
	
di "DONE!"

}


