/*

Heterogeneity by eq. effort

Generates tables with heterogeneity along the following dimensions: 
	- eq_effort

Author(s):
	Ismail Khan
	Garima Sharma
	Guillermo Palacios

*/

*************************************************************
* Initial Setup
*************************************************************

clear all
set more off
set trace off
cap cd "${TP_ANALYSIS}"
do "Do Files/programs/all_programs.do"

*************************************************************
* Prepare datasets
*************************************************************

* Load and temporarily save Y2 data
use "Coded Data/150525 TP Analysis Data FULL SAMPLE", clear
keep circle_id qtr ln_gross_* ln_net_* ln_recov_*
foreach var in recov_tot net_dem gross_dem {
	foreach x in c a t {
		ren ln_`var'_`x' y1_ln_`var'_`x'
	}
}
merge 1:1 circle_id qtr using "Coded Data/TP Y2 Analysis Data w Y1 Treatment", keep(match)
drop if litigated == 1 // drop litigated circles
keep if qtr == 4
drop if treatment_y1 == 1
drop if mi(treatment_y1)
gen y1 = 0
label var treatment "Treatment"
tempfile y2_data
sa `y2_data'

* Load and temporarily save Y1 data
use "Coded Data/150525 TP Analysis Data", clear
drop if litigated == 1
keep if qtr == 4
gen y1 = 1
label var treatment "Treatment"
tempfile y1_data
sa `y1_data'

* Create pooled dataset
use `y1_data', clear
append using `y2_data'
gen base_y1_interact = .
tempfile pooled_data
sa `pooled_data'

* Load competitiveness data (using basic simulations)
use "Coded Data/Basic simulation results", clear
egen group_id = group(partition_name group) // * New sims dont have partition names, so we need to match these
quietly tab group_id, gen(group_dummy)
reshape long own_circle_id ranking, i(partition_name group hr_id) j(j)
drop j *mean *same ranking *choice
drop if mi(own_circle_id)
ren own_circle_id circle_id
ren (fraction_better_strict fraction_worse_strict fraction_better_weak fraction_worse_weak) /// 
	(fb_strict fw_strict fb_weak fw_weak)
tempfile basic_sim
sa `basic_sim'

*************************************************************
* Equilibrium effort
*************************************************************

forvalues h=1/4 {
local i: word `h' of "randk" "fullk" "zerok" "fullk"
local j: word `h' of "y1m" "y1m" "y1m" "zerom"
	
		* Load simulation results (y1)
		insheet using "output\Transfer simulations/eqeffort_avg_100iter_`j'_`i'.csv", comma clear
		merge 1:m hr_id group_id using `basic_sim', assert(match) nogen
		ren mean_eqeffort eq_effort
		tempfile sim_data_`j'_`i'
		
		* Normalize equilibrium efforts to mean 0, sd 1	
		sum eq_effort 
		gen eq_effort_std = (eq_effort - `r(mean)')/`r(sd)'
		sa `sim_data_`j'_`i'', replace
		
		* Add competitiveness measures to y1 dataset
		use `y1_data', clear
		merge m:1 circle_id using `sim_data_`j'_`i'', keep(match) nogen // _m == 1 for empty circles, _m == 2 for litigated circles
		gen interaction = .
		label var interaction	"Interaction"
		tempfile y1_data_`j'_`i'
		rename base_ln_recov_tot_t_growth base_ln_recov_tot_t_g
		rename base_ln_recov_tot_c_growth base_ln_recov_tot_c_g
		rename base_ln_recov_tot_a_growth base_ln_recov_tot_a_g
		sa `y1_data_`j'_`i'', replace
	
		* Add competitiveness measures to y2 dataset
		use `y2_data', clear
		merge m:1 circle_id using `sim_data_`j'_`i'', keep(match) nogen // _m == 1 for empty circles, _m == 2 for litigated circles
		gen interaction = .
		label var interaction	"Interaction"
		tempfile y2_data_`j'_`i'
		rename base_ln_recov_tot_t_growth base_ln_recov_tot_t_g
		rename base_ln_recov_tot_c_growth base_ln_recov_tot_c_g
		rename base_ln_recov_tot_a_growth base_ln_recov_tot_a_g
		sa `y2_data_`j'_`i'', replace
		
		* Generate pooled dataset
		use `y1_data_`j'_`i''
		append using `y2_data_`j'_`i''
		tempfile pooled_data_`j'_`i'
		save `pooled_data_`j'_`i''	
}

*************************************************************
* Marginal incentives at e=0
*************************************************************

foreach i in "zerok" "fullk" "randk" {
	foreach j in "zerom" "y1m" {
	
		* Load competitiveness data (using new simulations)
		insheet using "output\Transfer simulations/sim_i10000_`j'_`i'.csv", comma clear
		ren (v1 v2 v3 v4 v5) (group_id hr_id dEu1dy dEu2dy dEu3dy)
		foreach var in dEu1dy dEu2dy dEu3dy {
		sum `var'
		replace `var' = (`var' - `r(mean)')/`r(sd)'
		}
		merge 1:m hr_id group_id using `basic_sim', assert(match) nogen
		tempfile sim_data_`j'_`i'_mg
		sa `sim_data_`j'_`i'_mg'
		
		* Add competitiveness measures to pooled dataset
		use `pooled_data', clear
		merge m:1 circle_id using `sim_data_`j'_`i'_mg', keep(match) nogen // _m == 1 for empty circles, _m == 2 for litigated circles
		gen interaction = .
		label var interaction	"Interaction"
		tempfile pooled_data_`j'_`i'_mg
		sa `pooled_data_`j'_`i'_mg', replace
		
		* Add competitiveness measures to y1 dataset
		use `y1_data', clear
		merge m:1 circle_id using `sim_data_`j'_`i'_mg', keep(match) nogen // _m == 1 for empty circles, _m == 2 for litigated circles
		gen interaction = .
		label var interaction	"Interaction"
		tempfile y1_data_`j'_`i'_mg
		sa `y1_data_`j'_`i'_mg', replace

		* Add competitiveness measures to y2 dataset
		use `y2_data', clear
		merge m:1 circle_id using `sim_data_`j'_`i'_mg', keep(match) nogen // _m == 1 for empty circles, _m == 2 for litigated circles
		gen interaction = .
		label var interaction	"Interaction"
		tempfile y2_data_`j'_`i'_mg
		sa `y2_data_`j'_`i'_mg', replace
	}
}

*************************************************************
* Run regressions for eq_effort
*************************************************************

eststo clear
estimates drop _all

forval i = 1/3 { // Zero vs full knowledge of P vs assume P is random; for now only (i) full knowledge & (ii) random P
	forval j = 1/2 { // zero vs full knowledge of y (Y1); for now only full knowledge

		local knowledge: word `i' of "fullk" "randk" "zerok"
		local base: word `j' of "y1m" "zerom"
		local var recov_tot
		
		if !(`i' == 2 & `j' == 2) & !(`i' == 3 & `j' == 2) { // Skip zerok/zerom and randk/zerom

			use `y2_data_`base'_`knowledge'', clear
			
			forvalues a=1/5 {
			local exo: word `a' of "base_ln_net_dem" "base_ln_gross_dem" "base_ln_recov_tot" "diff_recov_net" "diff_recov_gross" 
			local title: word `a' of "Net demand at baseline" "Gross demand at baseline" "Recovery at baseline" "Difference Recov - Net" "Difference Recov - Gross"
			gen `exo'=.
			gen interaction`exo'=.
			label var interaction`exo' "Treatment * `title'"
			}
			gen base_y1_interact=.			
			gen pre=.
			
			foreach x in t {
			
				replace base_y1_interact = y1 * base_ln_`var'_`x'
			
				forvalues a=1/3 {
				local exo: word `a' of "base_ln_net_dem" "base_ln_gross_dem" "base_ln_recov_tot" 
				local title: word `a' of "Net demand at baseline" "Gross demand at baseline" "Recovery at baseline"
				replace `exo'=`exo'_`x'
				replace interaction`exo'=`exo'_`x' * treatment
				}
				
				replace diff_recov_gross=base_ln_recov_tot-base_ln_gross_dem
				replace diff_recov_net=base_ln_recov_tot-base_ln_net_dem
				replace interactiondiff_recov_net= diff_recov_net * treatment
				replace interactiondiff_recov_gross= diff_recov_gross * treatment			
				replace pre=base_ln_`var'_`x' if y1==1
				replace pre=y1_ln_`var'_`x' if y1==0
				
				foreach comp_var in  eq_effort_std {
			
					replace interaction = `comp_var' * treatment
										
					forvalues a=1/2 {
					local eq: word `a' of "" "base_ln_gross_dem interactionbase_ln_gross_dem diff_recov_gross interactiondiff_recov_gross"
					eststo y2fe_`x'`i'`j'_`comp_var'_c`a': areg ln_`var'_`x' treatment base_ln_recov_tot_`x' interaction `comp_var'  `eq', a(group_id) cluster(circle_id)				
					qui sum ln_`var'_`x' if e(sample) == 1 & treatment == 0
					estadd scalar ymean = `r(mean)'					
					}		
				}
			}
		}	
	}
}
 
*************************************************************
* Run regressions for mg incentives
*************************************************************

forval i = 1/3 { // Zero vs full knowledge of P vs assume P is random; for now only (i) full knowledge & (ii) random P
	forval j = 1/2 { // zero vs full knowledge of y (Y1); for now only full knowledge

		local knowledge: word `i' of "fullk" "randk" "zerok"
		local base: word `j' of "y1m" "zerom"
		local var recov_tot
		
		if !(`i' == 2 & `j' == 2) & !(`i' == 3 & `j' == 2) { // Skip zerok/zerom and randk/zerom

			use `y2_data_`base'_`knowledge'_mg', clear
			
			rename dEu1dy eq_effort_std
			
			forvalues a=1/5 {
			local exo: word `a' of "base_ln_net_dem" "base_ln_gross_dem" "base_ln_recov_tot" "diff_recov_net" "diff_recov_gross" 
			local title: word `a' of "Net demand at baseline" "Gross demand at baseline" "Recovery at baseline" "Difference Recov - Net" "Difference Recov - Gross"
			gen `exo'=.
			gen interaction`exo'=.
			label var interaction`exo' "Treatment * `title'"
			}
			gen base_y1_interact=.			
			gen pre=.
			
			foreach x in t {
			
				replace base_y1_interact = y1 * base_ln_`var'_`x'
				
				forvalues a=1/3 {
				local exo: word `a' of "base_ln_net_dem" "base_ln_gross_dem" "base_ln_recov_tot" 
				local title: word `a' of "Net demand at baseline" "Gross demand at baseline" "Recovery at baseline"
				replace `exo'=`exo'_`x'
				replace interaction`exo'=`exo'_`x' * treatment
				}

				replace diff_recov_gross=base_ln_recov_tot-base_ln_gross_dem
				replace diff_recov_net=base_ln_recov_tot-base_ln_net_dem
				replace interactiondiff_recov_net= diff_recov_net * treatment
				replace interactiondiff_recov_gross= diff_recov_gross * treatment			
				replace pre=base_ln_`var'_`x' if y1==1
				replace pre=y1_ln_`var'_`x' if y1==0
			
				foreach comp_var in eq_effort_std  {
					
					replace interaction = `comp_var' * treatment
					
					*Analysis (4C)
					
					forvalues a=1/2 {
					local eq: word `a' of "" "base_ln_gross_dem interactionbase_ln_gross_dem diff_recov_gross interactiondiff_recov_gross"				
					eststo y2fe_`x'`i'`j'_dEu1dy_c`a': areg ln_`var'_`x' treatment base_ln_recov_tot_`x' interaction `comp_var'  `eq', a(group_id) cluster(circle_id)				
					qui sum ln_`var'_`x' if e(sample) == 1 & treatment == 0
					estadd scalar ymean = `r(mean)'
					}
				}
			}
		}	
	}
}

*************************************************************
* Table 
*************************************************************

	label var interactionbase_ln_gross_dem "Treatment * Tax base at baseline"
	label var eq_effort_std "Model-predicted effort"
	label var interactiondiff_recov_net "Treatment * Recovery rate at baseline"
	label var diff_recov_net "Recovery rate at baseline "
	label var interactiondiff_recov_gross "Treatment * Recovery rate at baseline"
	label var diff_recov_gross "Recovery rate at baseline"

	local file heterogeneity_fe_paper_Y2
	
	* Panel A: Full knowledge of P, Y
	
	#delimit ;
	esttab y2fe_t11_eq_effort_std_c1  y2fe_t11_eq_effort_std_c2 y2fe_t11_dEu1dy_c1 y2fe_t11_dEu1dy_c2
	using "${TP_PAPER_OUTPUT}/tex/input/`file'_input.tex",
	order (interaction  interactionbase_ln_gross_dem interactiondiff_recov_gross  eq_effort_std )
	keep (interaction  interactionbase_ln_gross_dem interactiondiff_recov_gross  eq_effort_std )
	b(%12.3f) se(%12.3f) 
	nostar
	nomtitles	
	mgroups("Eq effort \textit{e}" "dEu/d\textit{e} at \textit{e}=0",
		pattern(1 0 1 0)
		prefix(\multicolumn{@span}{c}{)
		suffix(}) span erepeat(\cmidrule(lr){@span})
	)			
	coeflabels(interaction "Treatment * Model-predicted effort") starlevels(* .10 ** .05 *** .01) 
	refcat(interaction "\specialcell{\emph{Panel A: Full knowledge of P, Y}}", nolabel) stats(r2 , labels("R-squared") fmt("%12.3f")) label booktabs substitute("<" "$<$") fragment
	noobs
	replace
	;
	#delimit cr
		
	* Panel D: Random P, full Y
	
	#delimit ;
	esttab y2fe_t21_eq_effort_std_c1 y2fe_t21_eq_effort_std_c2 y2fe_t21_dEu1dy_c1 y2fe_t21_dEu1dy_c2
	using "${TP_PAPER_OUTPUT}/tex/input/`file'_input.tex", 
	order (interaction  interactionbase_ln_gross_dem interactiondiff_recov_gross  eq_effort_std )
	keep (interaction  interactionbase_ln_gross_dem interactiondiff_recov_gross  eq_effort_std )
	b(%12.3f) se(%12.3f) 
	nostar
	coeflabels(interaction "Treatment * Model-predicted effort") starlevels(* .10 ** .05 *** .01) 
	nomtitles
	nonumbers
	refcat(interaction "\emph{Panel B: Random P, full knowledge of Y}", nolabel) stats(r2 , labels("R-squared") fmt("%12.3f")) label booktabs substitute("<" "$<$") fragment	
	noobs
	append
	;
	#delimit cr	
	
	* Panel C: Assume identical P, no knowledge of Y
	
	#delimit ;
	esttab y2fe_t31_eq_effort_std_c1  y2fe_t31_eq_effort_std_c2 y2fe_t31_dEu1dy_c1 y2fe_t31_dEu1dy_c2
	using "${TP_PAPER_OUTPUT}/tex/input/`file'_input.tex", 
	order (interaction  interactionbase_ln_gross_dem interactiondiff_recov_gross  eq_effort_std )
	keep (interaction  interactionbase_ln_gross_dem interactiondiff_recov_gross  eq_effort_std )
	b(%12.3f) se(%12.3f) 
	nostar
	coeflabels(interaction "Treatment * Model-predicted effort") starlevels(* .10 ** .05 *** .01) 
	nomtitles
	nonumbers
	refcat(interaction "\emph{Panel C: Assume identical P, full knowledge of Y}", nolabel) stats(r2 , labels("R-squared") fmt("%12.3f"))	 label booktabs substitute("<" "$<$") fragment
	noobs
	append
	;
	#delimit cr
	
	* Panel B: Full knowledge of P, No knowledge of Y
	
	#delimit ;
	esttab y2fe_t12_eq_effort_std_c1  y2fe_t12_eq_effort_std_c2 y2fe_t12_dEu1dy_c1 y2fe_t12_dEu1dy_c2
	using "${TP_PAPER_OUTPUT}/tex/input/`file'_input.tex", 
	order (interaction  interactionbase_ln_gross_dem interactiondiff_recov_gross  eq_effort_std )
	keep (interaction  interactionbase_ln_gross_dem interactiondiff_recov_gross  eq_effort_std )
	b(%12.3f) se(%12.3f) 
	nostar
	coeflabels(interaction "Treatment * Model-predicted effort") starlevels(* .10 ** .05 *** .01) 
	nomtitles
	nonumbers
	refcat(interaction "\emph{Panel D: Full knowledge of P, no knowledge of Y}", nolabel)	stats(r2 N ymean, labels("R-squared" "N" "Mean of control group") fmt("%12.3f" "%12.0f" "%12.3f"))	 label booktabs substitute("<" "$<$") fragment	
	noobs
	append
	;
	#delimit cr
			

	** WRITE LaTeX WRAPPER AND COMPILE TO PDF **************************************

	set more off

	** WRITE TABLE NOTE

	file open tablenote using "${TP_PAPER_OUTPUT}/tex/notes/`file'_notes.txt", write replace

	file write tablenote "OLS regessions of log recovery on treatment assignment, with group fixed effects (Y2)."
	file write tablenote " The unit of observation is a circle, as defined at the time of randomization."
	file write tablenote " In Columns 1 and 2, the model-predicted effort is the Nash equilibrium level of effort. In Columns 3 and 4, effort corresponds to the marginal incentives evaluated at \textit{e}=0."
	file write tablenote " Columns 2 and 4 include tax base and recovery rate at baseline and their interactions with treatment assignment in the specification."
	file write tablenote " Robust standard errors in parentheses."
	file write tablenote " Standard errors are clustered by circle."

	file close tablenote

	texout2 "${TP_PAPER_OUTPUT}/tex/`file'", ///
	  input("input/`file'_input") notes("notes/`file'_notes")

	compiletex "${TP_PAPER_OUTPUT}/tex/`file'.tex", ///
	  out("..") aux("auxdir/")
