/*
Table for margins of impact in Year 1 and Year 2

Author(s):
	Ismail Khan (2015-)

Date created:
	Oct 23, 2015
*/

*************************************************************
* Initial setup
*************************************************************

clear all
set more off
cap cd "${TP_ANALYSIS}"
do "Do Files/programs/all_programs.do"

*************************************************************
* Prepare datasets
*************************************************************

* Load Y1 data (to be used as baseline)
use "Coded Data/150525 TP Analysis Data FULL SAMPLE", clear
keep circle_id qtr ln_gross_* ln_net_* ln_recov_* ln_recoveryrate* ln_nonexemptrate*
foreach var in recov_tot net_dem gross_dem recoveryrate nonexemptrate {
	foreach x in c a t {
		ren ln_`var'_`x' y1_ln_`var'_`x'
	}
}

* Load and temporarily save Y2 data
merge 1:1 circle_id qtr using "Coded Data/TP Y2 Analysis Data w Y1 Treatment", keep(match)
drop if litigated == 1 // drop litigated circles
keep if qtr == 4
drop if treatment_y1 == 1
drop if mi(treatment_y1)
gen y1 = 0
label var treatment "Treatment"
label var DEM_sel "Demand"
label var REV_sel "Revenue"
gen base_recov = .
gen base_net_dem = .
gen base_gross_dem = .

tempfile y2_data
sa `y2_data'

* Load and temporarily save Y1 data
use "Coded Data/150525 TP Analysis Data", clear
drop if litigated == 1
keep if qtr == 4
gen y1 = 1
label var treatment "Treatment"
label var DEM_sel "Demand"
label var REV_sel "Revenue"
gen base_recov = .
gen base_net_dem = .
gen base_gross_dem = .

tempfile y1_data
sa `y1_data'

* Create pooled dataset
use `y1_data', clear
append using `y2_data'
gen base_recov_y1_interact = .
gen base_net_dem_y1_interact = .
gen base_gross_dem_y1_interact = .
forval i = 1/33 {
	gen stratdum_y1_interact`i' = y1 * stratdum`i'
	replace stratdum`i' = 0 if mi(stratdum`i')
	replace stratdum_y1_interact`i' = 0 if mi(stratdum_y1_interact`i')
}
tempfile pooled_data
sa `pooled_data'


*************************************************************
* Run Regressions - Any treatment
*************************************************************

* Overall Treatment
local file margins_of_impact_paper

* Y1 outcomes
use `y1_data', clear
foreach x in recov_tot gross_dem nonexemptrate recoveryrate {

	replace base_recov = base_ln_recov_tot_t
	replace base_net_dem = base_ln_net_dem_t
	replace base_gross_dem = base_ln_gross_dem_t
	
	* Any treatment
	eststo y1_`x' : 	reg ln_`x'_t treatment base_recov base_net_dem base_gross_dem, cluster(circle_id)
	qui sum ln_`x'_t if e(sample) == 1 & treatment == 0
	estadd scalar ymean = `r(mean)'
	
	* By sub-treatment
	eststo y1_`x'_sub : reg ln_`x'_t REV_sel DEM_sel base_recov base_net_dem base_gross_dem, cluster(circle_id)
	qui sum ln_`x'_t if e(sample) == 1 & treatment == 0
	estadd scalar ymean = `r(mean)'
}

* Y2 outcomes
use `y2_data', clear
foreach x in recov_tot gross_dem nonexemptrate recoveryrate {
	
	* Any treatment
	replace base_recov = base_ln_recov_tot_t
	replace base_net_dem = base_ln_net_dem_t
	replace base_gross_dem = base_ln_gross_dem_t
	eststo y2_`x' : 	reg ln_`x'_t treatment base_recov base_net_dem base_gross_dem, cluster(circle_id)
	qui sum ln_`x'_t if e(sample) == 1 & treatment == 0
	estadd scalar ymean = `r(mean)'

	* By sub-treatment
	eststo y2_`x'_sub : reg ln_`x'_t REV_sel DEM_sel base_recov base_net_dem base_gross_dem, cluster(circle_id)
	qui sum ln_`x'_t if e(sample) == 1 & treatment == 0
	estadd scalar ymean = `r(mean)'

}

* Pooled outcomes
use `pooled_data', clear
foreach x in recov_tot gross_dem nonexemptrate recoveryrate {
	
	* Any treatment
	replace base_recov = base_ln_recov_tot_t
	replace base_net_dem = base_ln_net_dem_t
	replace base_gross_dem = base_ln_gross_dem_t
	replace base_recov_y1_interact = y1 * base_recov
	replace base_net_dem_y1_interact = y1 * base_net_dem
	replace base_gross_dem_y1_interact = y1 * base_gross_dem
	eststo pl_`x' : 		reg ln_`x'_t treatment base_recov base_net_dem base_gross_dem base_recov_y1_interact base_net_dem_y1_interact base_gross_dem_y1_interact y1, cluster(circle_id)
	qui sum ln_`x'_t if e(sample) == 1 & treatment == 0
	estadd scalar ymean = `r(mean)'
	
	* By sub-treatment
	eststo pl_`x'_sub : 	reg ln_`x'_t REV_sel DEM_sel base_recov base_net_dem base_gross_dem base_recov_y1_interact base_net_dem_y1_interact base_gross_dem_y1_interact y1, cluster(circle_id)
	qui sum ln_`x'_t if e(sample) == 1 & treatment == 0
	estadd scalar ymean = `r(mean)'
	qui test REV_sel == DEM_sel
	estadd scalar ftest = `r(p)'
	eststo pl_`x'_sub
}


* No strata FE, FY 2013 as baseline
# delimit ;
esttab pl_recov_tot pl_gross_dem pl_nonexemptrate pl_recoveryrate
	using "${TP_PAPER_OUTPUT}/tex/input/`file'_input.tex", 
	keep(treatment)
	
	b(%12.3f)
	se(%12.3f)
	
	nostar
	mtitles(
		"Revenue" "Tax Base" "\specialcell{Non-Exemption \\ Rate}" "\specialcell{Recovery \\ Rate}"
	) // Column headings
	
	refcat(
		treatment "\specialcell{\emph{Panel A: Any treatment}}", nolabel
	)
	noobs		
	label // Use Variable Labels
	booktabs // a nicer version of tables
	substitute("<" "$<$")
	fragment
	// append
	replace
	;

# delimit cr


* No strata FE, previous year as Baseline
# delimit ;
esttab 	pl_recov_tot_sub pl_gross_dem_sub pl_nonexemptrate_sub pl_recoveryrate_sub
	using "${TP_PAPER_OUTPUT}/tex/input/`file'_input.tex", 
	keep(REV_sel DEM_sel)
	
	b(%12.3f)
	se(%12.3f)
	
	nostar
	refcat(
		REV_sel "\specialcell{\emph{Panel B: Sub-treatment}}", nolabel
	)
	
	stats(N ymean ftest,
		labels(
			"N"
			"Mean of control group"
			"Revenue = Demand (p-value)"
		)	
		fmt(
			"%12.0f" "%12.3f" "%12.3f"
		)
	)	
	
	label // Use Variable Labels
	nomtitles
	nonumbers
	booktabs // a nicer version of tables
	substitute("<" "$<$")
	fragment
	append
	;

# delimit cr

eststo clear

** WRITE LaTeX WRAPPER AND COMPILE TO PDF **************************************

set more off

** WRITE TABLE NOTE

file open tablenote using "${TP_PAPER_OUTPUT}/tex/notes/`file'_notes.txt", write replace

file write tablenote "OLS regessions of various  margins on treatment assignment."
file write tablenote " The unit of observation is a circle, as defined at the time of randomization."
file write tablenote " Sample consists of pooled year 1 and year 2 observations."
file write tablenote " Year 1 sample includes all circles and Year 2 consists of circles that were in the control group in year 1."
file write tablenote " Specification controls for baseline value."
file write tablenote " Robust standard errors in parentheses."
file write tablenote " Standard errors are clustered by circle."

file close tablenote

texout2 "${TP_PAPER_OUTPUT}/tex/`file'", ///
  input("input/`file'_input") notes("notes/`file'_notes")

compiletex "${TP_PAPER_OUTPUT}/tex/`file'.tex", ///
  out("..") aux("auxdir/")  

  
