/*
Y1 preferences analysis (circle-level results).  Includes RI.

*/

* Initial setup
clear all
set more off
pause off
set maxvar 30000
cap cd "${TP_ANALYSIS}"
do "Do Files/programs/all_programs.do"


*************************************************************
* 1. Prepare randomized files for analysis
*************************************************************

local num 2000

*************************************************************
* Define a program for storing p values from Rand Inference
*************************************************************

cap prog drop add_pval 
program define add_pval, eclass // Name of the command
syntax,  results(string) pval(real) indvar(string) // Associate p with estimates of y, local pval and indep variable indvar.

estimates restore `results'

matrix pval=J(1,1,.) // Opens a space for pvalue
matrix colnames pval="`indvar'" 

matrix pval[1,1]=`pval' // Defines where the value comes from

estadd matrix pval pval // Stores the matrix

end

*************************************************************
* Define a program for storing p values from Rand Inference
*************************************************************

cap prog drop add_pval2
program define add_pval2, eclass // Name of the command
syntax,  results(string) pval1(real) pval2(real) indvar1(string) indvar2(string) // Associate p with estimates of y, local pval and indep variable indvar.

estimates restore `results'

matrix pval=J(1,2,.) // Opens a space for pvalue
matrix colnames pval="`indvar1'" "`indvar2'" 

matrix pval[1,1]=`pval1' // Defines where the value comes from
matrix pval[1,2]=`pval2' // Defines where the value comes from

estadd matrix pval pval // Stores the matrix

end

*************************************************************
* 1. Prepare original dataset for analysis
*************************************************************

* Load inspector-level preference data
use "Coded Data/Y1 Preferences analysis data", clear
tempfile hr_level_tables
sa `hr_level_tables'

*************************************************************
* 2. Prepare original dataset for analysis
*************************************************************

quietly {
use `hr_level_tables', clear
keep if !mi(current_circle_id)
rename current_circle_id circle_id
merge 1:1 circle_id using "Coded Data/RI/rand_code_iter", keep(3) keepusing(treatment_y2_*)
drop treatment_y2
forvalues m=1/`num' {
preserve
rename treatment_y2_`m' treatment_y2
drop continuin* treatment_y2_*
gen continuing_`m'=treatment_y2==1
tempfile pref_analysis_data_`m'
save `pref_analysis_data_`m''
restore
}
}

*************************************************************
* 3. Regressions on inspector-level preference data
*************************************************************

* Inspector level results

* Without baseline

	foreach var in own_circle_favorite own_circle_u1 {

		tempname `var'_rand
		postfile ``var'_rand' b_continuing se_continuing using `var'_rand.dta, replace 
		forval m = 1/`num' {
		use `pref_analysis_data_`m'', clear
		reg `var' continuing_`m', cluster(hr_id)
		post ``var'_rand' (_b[continuing_`m']) (_se[continuing_`m']) 
		}
		postclose ``var'_rand'
		

	use `hr_level_tables', clear
		
		eststo `var' : reg `var' continuing, cluster(hr_id)
		gen reg_sample = e(sample) == 1
		qui sum `var' if reg_sample == 1 & continuing == 0
		estadd scalar ymean = `r(mean)'
		qui count if reg_sample == 1
		drop reg_sample
		scalar b_continuingb = _b[continuing]
		estadd scalar b_continuingb = _b[continuing]
		
	use `var'_rand.dta, clear

		preserve
		keep if abs(b_continuing)> abs(`=b_continuingb') 
		if _N==0{
			local b_continuingp= 0.001
			}
		else {
			local b_continuingp = _N / `num' 
			}
		display `b_continuingp'
		restore
			
	add_pval, results(`var') pval(`b_continuingp') indvar(continuing) 
	eststo `var'
	erase `var'_rand.dta
	
	}


* With baseline (for selected variables)

	foreach var in own_circle_favorite own_circle_u1  {

		tempname `var'_base_rand
		postfile ``var'_base_rand' b_continuing se_continuing b_`var'_base se_`var'_base using `var'_base_rand.dta, replace 
		forval m = 1/`num' {
		use `pref_analysis_data_`m'', clear
		reg `var' continuing_`m' `var'_base, cluster(hr_id)
		post ``var'_base_rand' (_b[continuing_`m']) (_se[continuing_`m'])  (_b[`var'_base]) (_se[`var'_base])
		}
		postclose ``var'_base_rand'

	use `hr_level_tables', clear
		eststo `var'_base : reg `var' continuing `var'_base, cluster(hr_id)
		
		gen reg_sample = e(sample) == 1
		qui sum `var' if reg_sample == 1 & continuing == 0
		estadd scalar ymean = `r(mean)'
		qui count if reg_sample == 1
		drop reg_sample
		scalar b_continuingb = _b[continuing]
		estadd scalar b_continuingb = _b[continuing]
		scalar b_`var'_baseb = _b[`var'_base]
		estadd scalar b_`var'_baseb = _b[`var'_base]

	use `var'_base_rand.dta, clear

			preserve
			keep if abs(b_continuing)> abs(`=b_continuingb') 
			if _N==0{
				local b_continuingp= 0.001
				}
			else {
				local b_continuingp = _N / `num' 
				}
			display `b_continuingp'
			restore

	add_pval, results(`var'_base) pval(`b_continuingp') indvar(continuing) 
	eststo `var'_base	
	erase `var'_base_rand.dta
	
	}

local file y1_preferences_rand

# delimit ;
	esttab own_circle_favorite own_circle_favorite_base own_circle_u1 own_circle_u1_base
		using "${TP_PAPER_OUTPUT}/tex/input/`file'_input.tex",		
		keep(continuing own_circle_favorite_base own_circle_u1_base)
		cells(b(fmt(%12.3f) star)
		se(fmt(%12.3f) par)
		pval(fmt(%12.3f) par([ ]))
		)
		coeflabel (continuing "Continuing" own_circle_favorite_base "Own circle is favorite, baseline" own_circle_u1_base "Own circle rank, baseline")
		collabels(none)				
		starlevels(* .10 ** .05 *** .01) // significance levels

		stardrop(continuing own_circle_favorite_base own_circle_u1_base)
		
		mtitles(
			"\specialcell{Own circle \\ is favorite}"
			"\specialcell{Own circle \\ is favorite}"
			"\specialcell{Own circle \\ rank}"
			"\specialcell{Own circle \\ rank}"
		) // Column headings
		
		stats(N ymean,
			labels(
				"N"
				"Mean of non-continuing group"
			)	
			fmt(
				"%12.0f" "%12.3f"
			)
		)
		
		label // Use Variable Labels
		booktabs // a nicer version of tables
		substitute("<" "$<$")
		fragment
		replace
		;

# delimit cr

eststo clear

cap cd "${TP_ANALYSIS}"
do "Do Files/programs/all_programs.do"

** WRITE LaTeX WRAPPER AND COMPILE TO PDF **************************************

set more off

** WRITE TABLE NOTE

file open tablenote using "${TP_PAPER_OUTPUT}/tex/notes/`file'_notes.txt", write replace

file write tablenote "OLS regessions on continuing treatment assignment."
file write tablenote " Sample is restricted to Y1 treatment inspectors only."
file write tablenote " The unit of observation is an inspector."
file write tablenote " Robust standard errors in parentheses."
file write tablenote " Randomization inference based p-values in brackets."

file close tablenote

texout2 "${TP_PAPER_OUTPUT}/tex/`file'", ///
  input("input/`file'_input") notes("notes/`file'_notes")

compiletex "${TP_PAPER_OUTPUT}/tex/`file'.tex", ///
  out("..") aux("auxdir/") 

